/** \brief 32-bit timer with defined period
	\note Uses Timer1
	\note Requires F_CPU defined
	\note Requires interrupts enabled
 */
#ifndef SYSTICK_H
#define SYSTICK_H

#include <stdint.h>

/** \brief Init and start timer
	\param period Counter is incremented every period [ms]; range is limited
 */
void systick_init(uint16_t period);

/** \brief Get counter value
	\return 32-bit timer value (atomically)
	\note Turns on interrupts on exit
 */
uint32_t systick_val(void);

/** \brief Set counter to 0 (atomically)
	\note Turns on interrupts on exit
 */
void systick_reset(void);

#endif
